<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Systemovervågning</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Systemovervågning er et værktøj til at overvåge systembelastning i realtid, vise og styre processer og tjenester som kører på dit system.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current frequency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frequency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sockets</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logical processors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Virtualization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>L1i cache</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>L1d cache</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>L2 cache</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>L3 cache</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Load average</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File descriptors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Processes</source>
        <translation>Processer</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Host name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OS type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Up time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Ingen søgeresultater</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>aktiv</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>genindlæser</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inaktiv</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>mislykkedes</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>aktiverer</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>deaktiverer</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>ikke-fundet</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>dårlig-indstilling</translation>
    </message>
    <message>
        <source>error</source>
        <translation>fejl</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>sammenlagt</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskeret</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>indlæst</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>aktiveret</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>deaktiveret</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statisk</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>overgangsfase</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indirekte</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>aktiveret-kørslestid</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>maskeret</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>genereret</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>død</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>start-før</translation>
    </message>
    <message>
        <source>start</source>
        <translation>start</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>start-efter</translation>
    </message>
    <message>
        <source>running</source>
        <translation>kører</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>afsluttet</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>genindlæs</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>stop-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>stop-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>stop-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>stop-efter</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>final-sigterm</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>final-sigkill</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>mislykkedes</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>auto-genstart</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your CPU usage is higher than %1%!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your memory usage is higher than %1%!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cached</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buffers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cached swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dirty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mapped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Free swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slab</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Write speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sectors read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reads/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sectors written</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Writes completed </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Writes merged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Writes/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Vis genveje</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Afslutning af processen kan forårsage tab af data.
Er du sikker på, at du vil fortsætte?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Afslut proces</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Hvis processen tvinges til afslutte kan det forårsage tab af data.
Er du sikker på, at du vil fortsætte?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Hvis programmet tvinges til afslutte kan det forårsage tab af data.
Er du sikker på, at du vil fortsætte?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Tving afslutning</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scope:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ESSID</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Link quality</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Signal strength</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Noise level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MAC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RX packets</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RX bytes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RX errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RX dropped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RX overruns</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RX frame</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TX packets</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TX bytes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TX errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TX overruns</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TX carrier</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IPv4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IPv6</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TX dropped</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Kommandolinje</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Starttidspunkt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klik på det program, du vil afslutte</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Hukommelse</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disklæsning</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Diskskrivning</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Hukommelse</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Ikke aktiveret</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Samlet modtaget</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Samlet sendt</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Meget høj</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Høj</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Lav</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Meget lav</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Tilpas</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Ugyldig</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, fejl: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Kunne ikke skifte procesprioritet</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Programmer</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mine processer</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Alle processer</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Kunne ikke sætte proces på pause</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Kunne ikke genoptage proces</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Kunne ikke dræbe proces</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Ukendt fejl</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Kunne ikke sende signal til proces</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Kunne ikke afslutte proces</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 programmer og %2 processer kører)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Ingen respons</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Bakke</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Vis placeringen af kommandoen</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Afslut proces</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Genoptag proces</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Dræb proces</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Skift prioritet</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Suspender proces</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Tilpasset prioritet</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Skift</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Hukommelse</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Diskskrivning</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Disklæsning</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Bruger</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritet</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Protection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Kunne ikke indstille tjenestens opstartstype</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Fejl: Kunne ikke indstille tjenestens opstartstype pga. underprocessen som holdt op med at virke.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Navn på tjenesteinstans</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Opdater</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Genstart</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Opstartstype</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Belastning</translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="vanished">Aktiv</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>Sub</translation>
    </message>
    <message>
        <source>State</source>
        <translation type="vanished">Tilstand</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beskrivelse</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Opstartstype</translation>
    </message>
    <message>
        <source>Start State</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start Tactic</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Tving afslutning af program</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Udfold</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Kompakt</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processer</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Tjenester</translation>
    </message>
    <message>
        <source>Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <source>Administrator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Standard User</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <source>Edit account information</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>